
Tab-completion with custom (domain-specific) arg values is<br/>
constantly on a dev wish list for complex backend.

*   DEC 2022: Attempts to find an adequate solution for sizeable data yielded no results.

*   JAN 2023: The [earlier question][earlier_stack_question] received zero activity for a month<br/>
    (with a single silent downvote, auto-deleted by a bot).<br/>
    Request to restore it was &#127925; Shut Down In Flames.
    <!--
    It seeked recommendations which tend to be spammed by answers<br/>
    (controversially, some spam may actually help more than none).
    -->
  
*   FEB 2023: The [explanation hangs on the appropriate site][later_stack_question] now -<br/>
    recommendations are still very welcome there.<br/>
    But, with some patience for integration, `argrelay` itself already became satisfying enough.

[earlier_stack_question]: https://stackoverflow.com/q/74996560/441652
[later_stack_question]: https://softwarerecs.stackexchange.com/questions/85247/
